@@ -1,10 +1,8 @@
 package Firewall::Utils::Date;
 
-use 5.018;
 use Carp;
 use Moose;
 use namespace::autoclean;
-use Mojo::Util qw(dumper);
 
 sub getFormatedDate {
   my ( $self, @param ) = @_;
