@@ -1,11 +1,9 @@
 package Firewall::Utils::Ip;
 
-use 5.018;
 use Carp;
 use Moose;
 use namespace::autoclean;
 use Firewall::Utils::Set;
-use Mojo::Util qw(dumper);
 
 sub getRangeFromIpRange {
   my ( $self, $ipMin, $ipMax ) = @_;
