@@ -1,11 +1,9 @@
 package Firewall::Utils::Mail;
 
-use 5.018;
 use Carp;
 use Moose;
 use namespace::autoclean;
 use Mail::Sender;
-use Mojo::Util qw(dumper);
 
 has smtp => (
   is       => 'ro',
