@@ -1,12 +1,10 @@
 package Firewall::Utils::Set;
 
-use 5.018;
 use Carp;
 use Moose;
 use namespace::autoclean;
 use POSIX;
 use experimental 'smartmatch';
-use Mojo::Util qw(dumper);
 
 has mins => (
   is      => 'rw',
